@@ -1308,13 +1308,21 @@ class Experiment(object):
         self.config = config
         self.experiment_id = config.get(
             'experiment_id', timestamp(datetime.datetime.utcnow()))
-        self.experiment_name = config.get('experiment_name', self.experiment_id)
-        self.description = config.get('description', '')
         self.processes = config['processes']
         self.topology = config['topology']
         self.initial_state = config.get('initial_state', {})
         self.emit_step = config.get('emit_step')
 
+        # display settings
+        self.experiment_name = config.get('experiment_name', self.experiment_id)
+        self.description = config.get('description', '')
+        self.display_info = config.get('display_info', True)
+        self.progress_bar = config.get('progress_bar', True)
+        self.time_created = timestamp()
+        if self.display_info:
+            self.print_display()
+
+        # parallel settings
         self.invoke = config.get('invoke', InvokeProcess)
         self.parallel = {}
 
@@ -1323,12 +1331,14 @@ class Experiment(object):
         self.deriver_paths = {}
         self.find_process_paths(self.processes)
 
+        # initialize the state
         self.state = generate_state(
             self.processes,
             self.topology,
             self.initial_state)
 
-        emitter_config = config.get('emitter', {})
+        # emitter settings
+        emitter_config = config.get('emitter', 'timeseries')
         if isinstance(emitter_config, str):
             emitter_config = {'type': emitter_config}
         emitter_config['experiment_id'] = self.experiment_id
@@ -1343,6 +1353,7 @@ class Experiment(object):
         self.emit_configuration()
         self.emit_data()
 
+        # logging information
         log.info('experiment {}'.format(self.experiment_id))
 
         log.info('\nPROCESSES:')
@@ -1367,7 +1378,7 @@ class Experiment(object):
 
     def emit_configuration(self):
         data = {
-            'time_created': timestamp(),
+            'time_created': self.time_created,
             'experiment_id': self.experiment_id,
             'name': self.experiment_name,
             'description': self.description,
@@ -1544,8 +1555,9 @@ class Experiment(object):
 
                 time = future
                 self.local_time += full_step
-                # log.info('time: {}'.format(self.local_time))
 
+                if self.progress_bar:
+                    print_progress_bar(time, interval)
                 if self.emit_step is None:
                     self.emit_data()
                 elif emit_time <= time:
@@ -1557,11 +1569,44 @@ class Experiment(object):
             assert advance['time'] == time == interval
             assert len(advance['update']) == 0
 
-
     def end(self):
         for parallel in self.parallel.values():
             parallel.end()
 
+    def print_display(self):
+        date, time = self.time_created.split('.')
+        print('\nExperiment ID: {}'.format(self.experiment_id))
+        print('Created: {} at {}'.format(
+            date[4:6] + '/' + date[6:8] + '/' + date[0:4],
+            time[0:2] + ':' + time[2:4] + ':' + time[4:6]))
+        if self.experiment_name is not self.experiment_id:
+            print('Name: {}'.format(self.experiment_name))
+        if self.description:
+            print('Description: {}'.format(self.description))
+
+
+def print_progress_bar(
+        iteration,
+        total,
+        decimals=1,
+        length=50,
+):
+    """ Call in a loop to create terminal progress bar
+
+    Arguments:
+        iteration: (Required) current iteration
+        total:     (Required) total iterations
+        decimals:  (Optional) positive number of decimals in percent complete
+        length:    (Optional) character length of bar
+    """
+    # progress = ("{0:." + str(decimals) + "f}").format(100 * (iteration / float(total)))
+    progress = ("{0:." + str(decimals) + "f}").format(total - iteration)
+    filled_length = int(length * iteration // total)
+    bar = '█' * filled_length + '-' * (length - filled_length)
+    print(f'\r Progress:|{bar}| {progress} seconds remaining    ', end='\r')
+    # Print New Line on Complete
+    if iteration == total:
+        print()
 
 # Tests
 def test_recursive_store():
