@@ -60,7 +60,4 @@ class DeriveCounts(Deriver):
             counts[molecule] = int(concentration * mmol_to_counts)
 
         return {
-            'counts': counts}
-
-# register process by invoking upon import
-DeriveCounts()
+            'counts': counts}
\ No newline at end of file
